<?php
/**
* Checks controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checks.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Checks controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckControllerChecks extends JControllerAdmin
{

	/**
	* Method to get a model object, loading it if required.
	*
	* @param string $name   The model name. Optional.
	* @param string $prefix The class prefix. Optional.
	* @param array  $config Configuration array for model. Optional.
	*
	* @return  object  The model.
	*/
	public function getModel(
		$name = 'Check',
		$prefix = 'RoughcheckModel',
		$config = array('ignore_request' => true)
	) {
		$model = parent::getModel($name, $prefix, $config);
		return $model;
	}

	/**
	* Redirects to Check topics
	*
	* @return bool Always true
	*/
	public function checktopics()
	{
		// Initialise variables.
		$app = JFactory::getApplication();
		$cid = $this->input->post->get('cid', array(), 'array');

		// define the record identifier
		$urlVar = 'id';

		// Get the parent record id from either the toolbar (post) or link (get)
		$check_id	= (int) (count($cid) ? $cid[0] : $app->input->getInt($urlVar));

		$tmpl   = $app->input->getCmd('tmpl');
		$layout = $app->input->getCmd('layout', 'edit');
		$route  = 'index.php?option='.$this->option;
		$route .= '&view=checktopics';

		// Setup redirect info.
		if ($tmpl) {
			$route .= '&tmpl='.$tmpl;
		}

		if ($layout) {
			$route .= '&layout='.$layout;
		}
		$route .= '&id='.$check_id;

		$this->setRedirect(JRoute::_($route, false));

		return true;
	}

	/**
	* Redirects to Check questions
	*
	* @return bool Always true
	*/
	public function checkquestions()
	{
		// Initialise variables.
		$app = JFactory::getApplication();
		$cid = $this->input->post->get('cid', array(), 'array');

		// define the record identifier
		$urlVar = 'id';

		// Get the parent record id from either the toolbar (post) or link (get)
		$check_id	= (int) (count($cid) ? $cid[0] : $app->input->getInt($urlVar));

		$tmpl   = $app->input->getCmd('tmpl');
		$layout = $app->input->getCmd('layout', 'edit');
		$route  = 'index.php?option='.$this->option;
		$route .= '&view=checkquestions';

		// Setup redirect info.
		if ($tmpl) {
			$route .= '&tmpl='.$tmpl;
		}

		if ($layout) {
			$route .= '&layout='.$layout;
		}
		$route .= '&id=' . $check_id;

		$this->setRedirect(JRoute::_($route, false));

		return true;
	}


	/**
	* Method to toggle the featured setting of a list of checks.
	*
	* @return  void
	*/
	public function featured()
	{
		// Check for request forgeries
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$user   = JFactory::getUser();
		$ids    = $this->input->get('cid', array(), 'array');

		// Access checks.
		foreach ($ids as $i => $id)
		{
			if (!$user->authorise('core.edit.state', 'com_content.article.'.(int) $id))
			{
				// Prune items that you can't change.
				unset($ids[$i]);
				throw new Exception(JText::_('JLIB_APPLICATION_ERROR_EDITSTATE_NOT_PERMITTED'));
			}
		}

		if (empty($ids))
		{
			throw new Exception(JText::_('JERROR_NO_ITEMS_SELECTED'));
		}
		else
		{
			// Get the model.
			$model = $this->getModel();

			try
			{
				// Toggle the items feature
				$model->featured($ids);
			}
			catch (Exception $e)
			{
				JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
				throw new Exception($e->getMessage());
				return false;
			}
		}

		$msg = JText::_('COM_ROUGHCHECK_CHECK_FEATURE_TOGGLED');
		$this->setRedirect('index.php?option=com_roughcheck&view=checks', $msg);
	}

	/**
	* Method to save the submitted ordering values for records via AJAX.
	*
	* @return  void
	*/
	public function saveOrderAjax()
	{
		$pks = $this->input->post->get('cid', array(), 'array');
		$order = $this->input->post->get('order', array(), 'array');

		// Sanitize the input
		JArrayHelper::toInteger($pks);
		JArrayHelper::toInteger($order);

		// Get the model
		$model = $this->getModel();

		// Save the ordering
		$return = $model->saveorder($pks, $order);

		if ($return)
		{
			echo "1";
		}

		// Close the application
		JFactory::getApplication()->close();
	}
}
