<?php
/**
* Utility class working with Roughcheck topic lists
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: topics.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted Access');

/**
* Utility class working with Roughcheck topic lists
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @license    GNU General Public License version 3 or later; see LICENSE.txt
* @link       http://p-o.co.uk/
*/
abstract class JHtmlTopics
{
	/**
	* Cached array of the topics.
	*
	* @var    array
	*/
	protected static $items = null;

	/**
	* Get a list of the available topic items.
	*
	* @param boolean $all       True to include All (*)
	* @param boolean $translate True to translate All
	*
	* @return  string
	*/
	public static function existing($all = false, $translate = false)
	{
		if (empty(self::$items)) {
			try {
				// Get the database object and a new query object.
				$db		= JFactory::getDBO();
				$query	= $db->getQuery(true);

				// Build the query.
				$query->select('a.id AS value, a.title AS text');
				$query->select('a.title AS title_native');
				$query->from('#__roughcheck_check_topics AS a');
				$query->where('a.state >= 0');
				$app = JFactory::getApplication();
				$check_id = (int) $app->getUserState('filter.check_id');
				$query->where('a.check_id = ' . $check_id);
				$query->order('a.title');

				// Set the query and load the options.
				$db->setQuery($query);
				self::$items = $db->loadObjectList();
				if ($db->getErrorMsg()) {
					throw new Exception($db->getErrorMsg());
				}
			} catch (Exception $e) {
				JLog::add(
					__METHOD__ . '()',
					JLog::ERROR,
					COM_ROUGHCHECK
				);
				JLog::add(
					'Exception: '.$e->getMessage(),
					JLog::ERROR,
					COM_ROUGHCHECK
				);
				$this->setError($e->getMessage());
				return false;
			}

			if ($all) {
				array_unshift(
					self::$items, new JObject(
						array(
							'value' => '*',
							'text' => $translate
								? JText::alt('JALL', 'language')
								: 'JALL_LANGUAGE'
						)
					)
				);
			}
		}
		return self::$items;
	}
}
