<?php
/**
* Assessment report model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessmentreport.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment report model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelAssessmentreport extends JModelList
{

	private $_assessment;
	private $_topic;
	private $_check;

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$assessment = $this->getAssessment();
		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unable to get assessment', JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}

		$topic = $this->getTopic();
		if (!$topic) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unable to get topic', JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('q.id');
		$query->select('q.title');
		$query->select('q.check_id');
		$query->select('q.topic_id');
		$query->select('q.ordering AS question_ordering');
		$query->select('q.state');
		$query->select('q.risk_detail_id AS question_risk_detail_id');
		if ($db->name == 'postgresql') {
			$query->select('q.risk_trigger');
		} else {
			$case = 'CASE q.risk_trigger '
					. 'WHEN 0 THEN "f" '
					. 'WHEN 1 THEN "t" '
					. 'ELSE NULL '
					. 'END AS risk_trigger';
			$query->select($case);
		}
		$query->select('q.reward_detail_id AS question_reward_detail_id');
		if ($db->name == 'postgresql') {
			$query->select('q.reward_trigger');
		} else {
			$case = 'CASE q.reward_trigger '
					. 'WHEN 0 THEN "f" '
					. 'WHEN 1 THEN "t" '
					. 'ELSE NULL '
					. 'END AS reward_trigger';
			$query->select($case);
		}
		$query->select('q.modified, q.modified_by');
		$query->select('q.created, q.created_by');
		$query->select('q.checked_out, q.checked_out_time');

		$query->select('t.ordering AS topic_ordering');
		$query->select('t.title AS topic_title');
		$query->select('t.description AS topic_description');

		$query->select('b.id as assessment_id');

		$query->select('r.title AS risk_title');
		$query->select('r.image AS risk_image');
		$query->select('rw.title AS reward_title');
		$query->select('rw.image AS reward_image');

		$query->select('a.risk_detail_id AS response_risk_detail_id');
		$query->select('a.reward_detail_id AS response_reward_detail_id');
		if ($db->name == 'postgresql') {
			$query->select('a.response');
		} else {
			$case = 'CASE a.response '
					. 'WHEN 0 THEN "f" '
					. 'WHEN 1 THEN "t" '
					. 'ELSE NULL '
					. 'END AS response';
			$query->select($case);
		}
		$query->select('a.id as response_id');

		$query->select('a.description AS response_note');
		$query->select('q.description_yes AS question_description_yes');
		$query->select('q.description_no AS question_description_no');
		$query->from('#__roughcheck_check_questions AS q');
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS b '
			. 'ON q.check_id = b.check_id '
			. 'AND b.id = ' . $db->escape($assessment->id)
		);
		$query->join(
			'INNER',
			'#__roughcheck_check_topics AS t '
			. 'ON q.topic_id = t.id'
		);
		$query->select('rd.title AS question_risk_title');
		$query->select('rd.image AS question_risk_image');
		$query->join(
			'INNER',
			'#__roughcheck_risk_details AS rd '
			. 'ON q.risk_detail_id = rd.id'
		);

		$query->select('rwd.title AS question_reward_title');
		$query->select('rwd.image AS question_reward_image');
		$query->join(
			'INNER',
			'#__roughcheck_reward_details AS rwd '
			. 'ON q.reward_detail_id = rwd.id'
		);
		$query->join(
			'LEFT',
			'#__roughcheck_assessment_responses AS a '
			. 'ON q.id = a.question_id '
			. 'AND b.id = a.assessment_id'
		);

		$query->join(
			'LEFT',
			'#__roughcheck_risk_details AS r '
			. 'ON a.risk_detail_id = r.id'
		);
		$query->join(
			'LEFT',
			'#__roughcheck_reward_details AS rw '
			. 'ON a.reward_detail_id = rw.id'
		);

		$query->order('t.ordering, q.ordering');

		return $query;
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	public function getAssessmentStatus()
	{
		$ret = new stdClass;

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select(
			' count(*)'
			. ' from   #__roughcheck_check_questions q'
			. ' where  q.check_id = ' . $this->_check->id
			. ' and state = 1'
		);
		$db->setQuery($query);
		$ret->countof_questions = $db->loadResult();

		$query = $db->getQuery(true);
		$query->select(
			' count(*)'
			. ' from  #__roughcheck_assessment_responses w'
			. ' where w.assessment_id = ' . $this->_assessment->id
			. ' and   w.response IS NOT NULL'
		);
		$db->setQuery($query);
		$ret->countof_responses = $db->loadResult();

		$query = $db->getQuery(true);
		$query->select(
			' max(modified)'
			. ' from  #__roughcheck_assessment_responses w'
			. ' where w.assessment_id = ' . $this->_assessment->id
		);
		$db->setQuery($query);
		$ret->responses_modified = $db->loadResult();

		return $ret;
	}

	/**
	* Method to set an assessment
	*
	* @param int $assessment_id ID of the Assessment to load
	*
	* @return void
	*/
	public function setAssessment($assessment_id)
	{
		$table = $this->getTable('assessment');
		$table->load($assessment_id);
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown assessment: '.$id, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_assessment = $table;
	}

	/**
	* Method to get an array of data items.
	*
	* @return mixed An array of data items on success, false on failure.
	*/
	public function getAssessment()
	{
		if ($this->_assessment) {
			return $this->_assessment;
		}

		$app = JFactory::getApplication();
		$id = $app->input->getInt('assessment_id', 0);
		if (! $id) {
			$id = $app->input->getInt('id', 0);
		}
		$table = $this->getTable('assessment');
		$table->load($id);
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown assessment: '.$id, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_assessment = $table;

		return $this->_assessment;
	}

	/**
	* Method to get an array of data items.
	*
	* @return mixed An array of data items on success, false on failure.
	*/
	public function getCheck()
	{
		if ($this->_check) {
			return $this->_check;
		}
		if (!$this->_assessment) {
			$this->getAssessment();
		}

		$table = $this->getTable('check');
		$table->load($this->_assessment->check_id);
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown assessment: '.$id, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_check = $table;

		return $this->_check;
	}

	/**
	* Method to set an assessment topic
	*
	* @param int $topic_id ID of the Assessment to load
	*
	* @return void
	*/
	public function setTopic($topic_id)
	{
		$table = $this->getTable('checktopic');
		$table->load($topic_id);
		if (!$table->id) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('Unknown topic: '.$topic_id, JLog::DEBUG, COM_ROUGHCHECK);
			return false;
		}
		$this->_topic = $table;
	}

	/**
	* Method to get an array of data items.
	*
	* @return mixed An array of data items on success, false on failure.
	*/
	public function getTopic()
	{
		if ($this->_topic) {
			return $this->_topic;
		}

		$app = JFactory::getApplication();
		$topic_id = $app->input->getInt('topic_id', 0);

		if (!$topic_id) {
			$id = $app->input->getInt('id', 0);
			$table = $this->getTable('assessment');
			$table->load($id);
			if (!$table->id) {
				JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
				JLog::add('Unknown assessment: '.$id, JLog::DEBUG, COM_ROUGHCHECK);
				return false;
			}
			$db = $this->getDBO();
			$query = $db->getQuery(true);
			$query->select('MIN(ordering)');
			$query->from('#__roughcheck_check_topics');
			$query->where('check_id = ' . $db->escape($table->check_id));
			$query->where('state = 1');
			$db->setQuery($query);
			$topic_id = $db->loadResult($query);

			$query = $db->getQuery(true);
			$query->select('id');
			$query->from('#__roughcheck_check_topics');
			$query->where('check_id = ' . $db->escape($table->check_id));
			$query->where('ordering = ' . $db->escape($topic_id));
			$query->where('state = 1');
			$db->setQuery($query);
			$topic_id = $db->loadResult($query);
		}

		$table = $this->getTable('checktopic');
		$table->load($topic_id);
		$this->_topic = $table;

		return $this->_topic;
	}

	/**
	* Method to get the Next Topic id.
	*
	* @return int Next topic id or zero
	*/
	public function getNextTopic()
	{
		$topic = $this->getTopic();

		if (!$topic) {
			return 0;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('MIN(ordering)');
		$query->from('#__roughcheck_check_topics');
		$query->where('check_id = ' . $db->escape($topic->check_id));
		$query->where('ordering > ' . $db->escape($topic->ordering));
		$query->where('state = 1');
		$db->setQuery($query);
		$next_id = $db->loadResult($query);

		if (!$next_id) {
			return 0;
		}

		$query = $db->getQuery(true);
		$query->select('id');
		$query->from('#__roughcheck_check_topics');
		$query->where('check_id = ' . $db->escape($topic->check_id));
		$query->where('ordering = ' . $db->escape($next_id));
		$query->where('state = 1');
		$db->setQuery($query);
		$next_id = $db->loadResult($query);

		if (!$next_id) {
			$next_id = 0;
		}

		return $next_id;
	}

	/**
	* Method to get the Previous Topic id.
	*
	* @return int Next topic id or zero
	*/
	public function getPreviousTopic()
	{
		$topic = $this->getTopic();

		if (!$topic) {
			return 0;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('MAX(ordering)');
		$query->from('#__roughcheck_check_topics');
		$query->where('check_id = ' . $db->escape($topic->check_id));
		$query->where('ordering < ' . $db->escape($topic->ordering));
		$query->where('state = 1');
		$db->setQuery($query);
		$prev_id = $db->loadResult($query);

		if (!$prev_id) {
			return 0;
		}

		$query = $db->getQuery(true);
		$query->select('id');
		$query->from('#__roughcheck_check_topics');
		$query->where('check_id = ' . $db->escape($topic->check_id));
		$query->where('ordering = ' . $db->escape($prev_id));
		$query->where('state = 1');
		$db->setQuery($query);
		$next_id = $db->loadResult($query);

		if (!$prev_id) {
			$prev_id = 0;
		}

		return $prev_id;
	}

	/**
	* Method to get the risk profile available for this check.
	*
	* @return array of risk objects
	*/
	public function getRiskprofile()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available risk profile!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id, a.title, a.report_title');
		$query->select('a.unknown, a.positive, a.negative');
		$query->select('a.unknownimage, a.positiveimage, a.negativeimage');
		$query->from('#__roughcheck_risk_profiles as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.id = c.risk_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('c.state = 1');
		$query->where('a.state = 1');

		$db->setQuery($query);

		$result = $db->loadObject();

		return $result;
	}

	/**
	* Method to get the risk details available for this check.
	*
	* @return array of risk objects
	*/
	public function getRisks()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available risks!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id, a.title, a.image, a.description, a.ordering');
		$query->from('#__roughcheck_risk_details as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.risk_profile_id = c.risk_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('a.state = 1');
		$query->where('c.state = 1');
		$query->order('a.ordering');

		$db->setQuery($query);

		$result = $db->loadObjectList();

		return $result;
	}

	/**
	* Method to get the reward profile available for this check.
	*
	* @return array of risk objects
	*/
	public function getRewardprofile()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available reward profile!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id, a.title, a.report_title');
		$query->select('a.unknown, a.positive, a.negative');
		$query->select('a.unknownimage, a.positiveimage, a.negativeimage');
		$query->from('#__roughcheck_reward_profiles as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.id = c.reward_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('c.state = 1');
		$query->where('a.state = 1');

		$db->setQuery($query);

		$result = $db->loadObject();

		return $result;
	}

	/**
	* Method to get the reward details available for this check.
	*
	* @return array of risk objects
	*/
	public function getRewards()
	{
		$assessment = $this->getAssessment();

		if (!$assessment) {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'No assessment to find available rewards!',
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return false;
		}

		$db = $this->getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id, a.title, a.image, a.description, a.ordering');
		$query->from('#__roughcheck_reward_details as a');
		$query->join(
			'INNER',
			'#__roughcheck_checks AS c '
			. 'ON a.reward_profile_id = c.reward_profile_id'
		);
		$query->join(
			'INNER',
			'#__roughcheck_assessments AS d '
			. 'ON d.check_id = c.id '
		);
		$query->where('d.id = ' . $db->escape($assessment->id));
		$query->where('a.state = 1');
		$query->where('c.state = 1');
		$query->order('a.ordering desc');

		$db->setQuery($query);

		$result = $db->loadObjectList();

		return $result;
	}

	/**
	* Function to return the list of questions to response
	*
	* @return array list of questions
	*/
	public function getQuestions()
	{

		$db = $this->getDBO();
		$db->setQuery($this->getListQuery());
		$results = $db->loadObjectList();

		return $results;
	}
}
