<?php
/**
* Checkhelp model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checkhelp.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Checkhelp model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelCheckhelp extends JModelAdmin
{
	/**
	* Object variable to store saved question
	*
	* @var JTable Object loaded with question record
	*/
	private $_question = null;

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();

			return parent::canDelete($record);
		}
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.checkhelp', 'checkhelp',
			array('control' => 'jform', 'load_data' => $loadData)
		);
		if (empty($form)) {
			return false;
		}

		// Determine correct permissions to check.
		if ($this->getState('checkhelp.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('id', 'action', 'core.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('id', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$context = "$this->option.edit.$this->name";
		//'com_roughcheck.edit.checkhelp.data'
		$data = JFactory::getApplication()->getUserState(
			$context . '.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();

			// Set the question_id
			if (!$data->id) {
				$question = $this->getQuestion();
				if (!$question) {
					JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
					JLog::add(
						'Creating Question help with unknown question!',
						JLog::ERROR, COM_ROUGHCHECK
					);
					throw new Exception('An error occured');
				}
				JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
				JLog::add('Item is '.$data, JLog::ERROR, COM_ROUGHCHECK);
				$data->set('question_id', $question->id);
			}
		}

		return $data;
	}

	/**
	* Function to get the parent
	*
	* @return JTable object
	*/
	public function getQuestion()
	{
		if (! $this->_question) {
			$question_id = 0;
			$item = $this->getItem();
			if ($item->question_id) {
				$question_id = $item->question_id;
			} else {
				$context = "$this->option.edit.$this->name";
				$app = JFactory::getApplication();
				$question_id = $app->getUserState("$context.question_id", 0);
			}
			if (!$question_id) {
				return false;
			}
			$this->_question = $this->getTable('checkquestion');
			$this->_question->load($question_id);
		}
		return $this->_question;
	}

}
