<?php
/**
* Question model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checkquestion.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Question model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelCheckquestion extends JModelAdmin
{
	/**
	* Object variable to store saved parent
	*
	* @var JTable Object loaded with parent record
	*/
	private $_parent = null;

	/**
	* Object variable to store current item
	*
	* @var JTable Object loaded with current item
	*/
	private $_item = null;

	/**
	* Method to test whether a record can be deleted.
	*
	* @param object $record A record object.
	*
	* @return boolean True if allowed to delete the record.
	*                 Defaults to the permission set in the component.
	*/
	protected function canDelete($record)
	{
		if (!empty($record->id)) {
			if ($record->state != -2) {
				return ;
			}
			$user = JFactory::getUser();

			return parent::canDelete($record);
		}
	}

	/**
	* Method to get the form record.
	*
	* @param array   $data     Data for the form.
	* @param boolean $loadData True if the form is to load its own data
	*                          (default case), false if not.
	*
	* @return mixed A JForm object on success, false on failure
	*/
	public function getForm($data = array(), $loadData = true) 
	{
		// Get the form.
		$form = $this->loadForm(
			'com_roughcheck.checkquestion',
			'checkquestion',
			array(
				'control' => 'jform',
				'load_data' => $loadData
			)
		);
		if (empty($form)) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'There is no form!',
				JLog::ERROR, COM_ROUGHCHECK
			);
			throw new Exception('There is no form!');
			return false;
		}

		// Determine correct permissions to check.
		if ($this->getState('check.id')) {
			// Existing record. Can only edit in selected categories.
			$form->setFieldAttribute('id', 'action', 'core.edit');
		} else {
			// New record. Can only create in selected categories.
			$form->setFieldAttribute('id', 'action', 'core.create');
		}

		// Modify the form based on access controls.
		if (!$this->canEditState((object) $data)) {
			// Disable fields for display.
			$form->setFieldAttribute('ordering', 'disabled', 'true');
			$form->setFieldAttribute('state', 'disabled', 'true');

			// Disable fields while saving.
			// The controller has already verified this is a record you can edit.
			$form->setFieldAttribute('ordering', 'filter', 'unset');
			$form->setFieldAttribute('state', 'filter', 'unset');
		}

		return $form;
	}

	/**
	* Method to get the data that should be injected in the form.
	*
	* @return mixed The data for the form.
	*/
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$context = "$this->option.edit.$this->name";
		$data = JFactory::getApplication()->getUserState(
			$context . '.data', array()
		);
		if (empty($data)) {
			$data = $this->getItem();
		} else {
			$data = JArrayHelper::toObject($data, 'JObject');
		}

		// Set the check_id
		if (!$data->id) {
			$parent = $this->getParent();
			if (!$parent) {
				JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
				JLog::add(
					'Creating Question with unknown parent!',
					JLog::ERROR, COM_ROUGHCHECK
				);
				throw new Exception('An error occured');
			}
			$data->set('check_id', $parent->id);
		}

		// If no topic_id is set then get the largest one
		if (!$data->topic_id) {
			$db = $this->getDbo();
			$query = $db->getQuery(true);
			$query->select('MAX(id)');
			$query->from('#__roughcheck_check_topics');
			$query->where('check_id = ' . (int)$data->check_id);
			$db->setQuery($query);
			$data->topic_id = $db->loadResult();
		}

		return $data;
	}

	/**
	* Method to get a topic
	*
	* @return JTable Loaded with the topic id if available
	*/
	public function getTopic()
	{
		$data  = $this->input->post->get('jform', array(), 'array');
		$id = $data['id'];
		if ($id) {
			$rd_table = $this->getTable();
			$rd_table->load($id);
			$table = $this->getTable('checktopic');
			$table->load($rd_table->topic_id);
		} else {
			$topic_id = $data['topic_id'];
			$table = $this->getTable('checktopic');
			$table->load($topic_id);
		}

		return $table;
	}

	/**
	* Method to get a single record.
	*
	* @param integer $pk The id of the primary key.
	*
	* @return mixed Object on success, false on failure.
	*/
	public function getItem($pk = null)
	{
		if (empty($this->_item)) {
			$this->_item = parent::getItem($pk);
		}
		return $this->_item;
	}

	/**
	* Function to get the parent
	*
	* @return JTable object
	*/
	public function getParent()
	{
		if (! $this->_parent) {
			$check_id = 0;
			$item = $this->getItem();
			if ($item->check_id) {
				$check_id = $item->check_id;
			} else {
				$context = "$this->option.edit.$this->name";
				$app = JFactory::getApplication();
				$check_id = $app->getUserState("$context.check_id", 0);
			}
			if (!$check_id) {
				return false;
			}
			$this->_parent = $this->getTable('check');
			$this->_parent->load($check_id);
		}
		return $this->_parent;
	}
}
