<?php
/**
* Roughcheck model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: roughcheck.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Roughcheck model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelRoughcheck extends JModelLegacy
{
	/**
	* Returns existance of data
	*
	* @return bool True if existing data, false if there is none
	*/
	public function getManifest()
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('manifest_cache');
		$query->from($db->quoteName('#__extensions'));
		$query->where('name = ' . $db->quote(COM_ROUGHCHECK));
		$db->setQuery($query);
		$manifest = $db->loadResult();
		$registry = new JRegistry();
		$registry->loadString($manifest);
		return $registry;
	}

	/**
	* Returns existance of data
	*
	* @return bool True if existing data, false if there is none
	*/
	public function getHasData()
	{
		$total = 0;

		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('count(*)');
		$query->from($db->quoteName('#__roughcheck_help_types'));
		$db->setQuery($query);
		$max = $db->loadResult();
		$total += $max;

		$query = $db->getQuery(true);
		$query->select('count(*)');
		$query->from($db->quoteName('#__roughcheck_risk_profiles'));
		$db->setQuery($query);
		$max = $db->loadResult();
		$total += $max;

		$query = $db->getQuery(true);
		$query->select('count(*)');
		$query->from($db->quoteName('#__categories'));
		$query->where('extension = ' . $db->quote('com_roughcheck'));
		$db->setQuery($query);
		$max = $db->loadResult();
		$total += $max;

		if ($total == 0) {
			return false;
		} else {
			return true;
		}
	}

	/**
	* Method to install starter data
	*
	* @return boolean True on success
	*/
	public function installstarterdata()
	{
		// Initialise variables.
		// Get current user
		$user = JFactory::getUser();
		$dispatcher = JDispatcher::getInstance();
		$db = JFactory::getDBO();
		$isNew = true;

		// Check we are allowed to create data
		$canDo	= RoughcheckHelper::getActions();
		$user	= JFactory::getUser();

		if (!$canDo->get('core.create')) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'Trying to install sample data without core.create',
				JLog::ERROR, COM_ROUGHCHECK
			);
			return false;
		}

		$query = $db->getQuery(true);
		$query->select('count(*)');
		$query->from($db->quoteName('#__roughcheck_help_types'));

		$db->setQuery($query);
		$max = $db->loadResult();

		// Check that there are no help types
		if ($max > 0) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Help types exist', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$query = $db->getQuery(true);
		$query->select('count(*)');
		$query->from($db->quoteName('#__roughcheck_risk_profiles'));

		$db->setQuery($query);
		$max = $db->loadResult();

		// Check that there are no risk profiles
		if ($max > 0) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Risk profiles exist', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Import JTableCategory
		JLoader::register(
			'JTableCategory',
			JPATH_PLATFORM . '/joomla/database/table/category.php'
		);
		$table = new JTableCategory($db);

		if (! $table) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'Unable to create new JTableCategory',
				JLog::ERROR, COM_ROUGHCHECK
			);
		}

		$data = array();
		$data['id'] = 0;
		$data['parent_id'] = 0;
		$data['level'] = 1;
		$data['extension'] = COM_ROUGHCHECK;
		$data['title'] = JText::_('COM_ROUGHCHECK_SAMPLEDATA_CATEGORY_UNKNOWN');
		$data['description'] = JText::_('COM_ROUGHCHECK_SAMPLEDATA_CATEGORY_UNKNOWN_DESC');
		$data['params'] = '{}';
		$data['metakey'] = '';
		$data['metadesc'] = '';
		$data['metadata'] = '';
		$data['rules'] = array('core.delete'=>'','core.edit'=>'','core.edit.state'=>'');
		$data['published'] = 1;
		$data['language'] = '*';

		// Set the new parent id
		$table->setLocation($data['parent_id'], 'last-child');

		// Bind the data.
		if (!$table->bind($data)) {
			$this->setError($table->getError());
			JLog::add('bind', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Check the data.
		if (!$table->check()) {
			$this->setError($table->getError());
			JLog::add('check', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Trigger the onContentBeforeSave event.
		//$result = $dispatcher->trigger(
		//	$this->event_before_save,
		//	array($this->option . '.' . $this->name, &$table, $isNew)
		//);
		//if (in_array(false, $result, true)) {
		//	$this->setError($table->getError());
		//	JLog::add('trigger', JLog::ERROR, COM_ROUGHCHECK);
		//	return false;
		//}

		// Store the data.
		if (!$table->store()) {
			$this->setError($table->getError());
			JLog::add('store', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Trigger the onContentAfterSave event.
		//$dispatcher->trigger(
		//	$this->event_after_save,
		//	array($this->option . '.' . $this->name, &$table, $isNew)
		//);

		// Rebuild the path for the category:
		if (!$table->rebuildPath($table->id)) {
			$this->setError($table->getError());
			JLog::add('rebuildpath', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Rebuild the paths of the category's children:
		if (!$table->rebuild(
			$table->id, $table->lft, $table->level, $table->path
		)) {
			$this->setError($table->getError());
			JLog::add('rebuild', JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$this->setState($this->getName() . '.id', $table->id);

		// Insert help type FAQ
		$data = $this->getTable('help');
		$data->ordering = 1;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_FAQ');
		$data->language = '*';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_FAQ_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding faq', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Insert help type Glossary
		$data = $this->getTable('help');
		$data->ordering = 2;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_GLOSSARY');
		$data->language = '*';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_GLOSSARY_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Glossary', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Insert risk type High Medium Low
		$data = $this->getTable('risk');
		$data->ordering = 1;
		$data->state = 1;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_TITLE');
		$data->report_title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_REPORTTITLE');
		$data->unknown = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_UNKNOWN');
		$data->unknownimage = 'components/com_roughcheck/images/unknown.png';
		$data->positive = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_POSITIVE');
		$data->positiveimage = 'components/com_roughcheck/images/cross.png';
		$data->negative = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_NEGATIVE');
		$data->negativeimage = 'components/com_roughcheck/images/tick.png';
		$data->language = '*';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding High Medium Low', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}
		$_risk_type_hml = $data->id;


		// Insert risk detail High
		$data = $this->getTable('riskdetail');
		$data->risk_profile_id = $_risk_type_hml;
		$data->ordering = 1;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_HIGH');
		$data->image = 'components/com_roughcheck/images/tlr.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_HIGH_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding High risk', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$data = $this->getTable('riskdetail');
		$data->risk_profile_id = $_risk_type_hml;
		$data->ordering = 2;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_MEDIUM');
		$data->image = 'components/com_roughcheck/images/tly.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_MEDIUM_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Medium risk', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$data = $this->getTable('riskdetail');
		$data->risk_profile_id = $_risk_type_hml;
		$data->ordering = 3;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_LOW');
		$data->image = 'components/com_roughcheck/images/tlg.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_LOW_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Low risk', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$data = $this->getTable('riskdetail');
		$data->risk_profile_id = $_risk_type_hml;
		$data->ordering = 4;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_NA');
		$data->image = 'components/com_roughcheck/images/tln.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_RISK_NA_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding na risk', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		// Insert reward type Gold silver bronze
		$data = $this->getTable('reward');
		$data->id = 0;
		$data->ordering = 1;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = 'Gold Silver Bronze';
		$data->unknown = 'Potential';
		$data->positive = 'Confirmed';
		$data->negative = 'Avoided';
		$data->language = '*';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_DESC');
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_TITLE');
		$data->report_title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_REPORTTITLE');
		$data->unknown = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_UNKNOWN');
		$data->unknownimage = 'components/com_roughcheck/images/unknown.png';
		$data->positive = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_POSITIVE');
		$data->positiveimage = 'components/com_roughcheck/images/tick.png';
		$data->negative = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_NEGATIVE');
		$data->negativeimage = 'components/com_roughcheck/images/cross.png';
		$data->language = '*';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Gold', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}
		$_reward_type_gold = $data->id;

		// Insert reward detail High
		$data = $this->getTable('rewarddetail');
		$data->id = 0;
		$data->reward_profile_id = $_reward_type_gold;
		$data->ordering = 1;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_HIGH');
		$data->image = 'components/com_roughcheck/images/gold.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_HIGH_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Gold reward', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$data = $this->getTable('rewarddetail');
		$data->reward_profile_id = $_reward_type_gold;
		$data->ordering = 2;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_MEDIUM');
		$data->image = 'components/com_roughcheck/images/silver.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_MEDIUM_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Medium reward', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$data = $this->getTable('rewarddetail');
		$data->reward_profile_id = $_reward_type_gold;
		$data->ordering = 3;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_LOW');
		$data->image = 'components/com_roughcheck/images/bronze.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_LOW_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add('Failed adding Low reward', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		$data = $this->getTable('rewarddetail');
		$data->reward_profile_id = $_reward_type_gold;
		$data->ordering = 4;
		$data->state = 1;
		$data->checked_out = 0;
		$data->checked_out_time = 0;
		$data->created_by = $user->id;
		$data->modified_by = $user->id;
		$data->title = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_NA');
		$data->image = 'components/com_roughcheck/images/blank.png';
		$data->description = JText::_('COM_ROUGHCHECK_SAMPLEDATA_REWARD_NA_DESC');
		try
		{
			$data->check();
			$data->store();
			$data->checkin();
		}
		catch (Exception $e)
		{
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add($e->getMessage(), JLog::ERROR, COM_ROUGHCHECK);
			return false;
		}

		return true;
	}

}
