<?php
/**
* Check table
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: check.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Check table class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class TableCheck extends JTable
{

	/**
	* Constructor
	*
	* @param object &$db Database connector object
	*/
	function __construct( &$db )
	{
		parent::__construct('#__roughcheck_checks', 'id', $db);
	}

	/**
	* Override bind Method to allow saving rules in asset table
	*
	* @param mixed $src    An associative array or object to bind
	*                      to the JTable instance.
	* @param mixed $ignore An optional array or space separated list
	*                      of properties to ignore while binding.
	*
	* @return  boolean  True on success.
	*/
	public function bind($src, $ignore = '')
	{
		// Bind the rules. 
		if (isset($src['rules']) && is_array($src['rules'])) { 
			$rules = new JAccessRules($src['rules']); 
			$this->setRules($rules); 
		}
		if (isset($src['params']) && is_array($src['params'])) {
			$registry = new JRegistry();
			$registry->loadArray($src['params']);
			$src['params'] = (string)$registry;
		}
		if (isset($src['metadata']) && is_array($src['metadata'])) {
			$registry = new JRegistry();
			$registry->loadArray($src['metadata']);
			$src['metadata'] = (string)$registry;
		}
		return parent::bind($src, $ignore);
	}

	/**
	* Method to compute the default name of the asset.
	* The default name is in the form table_name.id
	* where id is the value of the primary key of the table.
	*
	* @return  string
	*/
//@codingStandardsIgnoreStart
	protected function _getAssetName()
	{
		$k = $this->_tbl_key;
		return 'com_roughcheck.check.' . (int) $this->$k;
	}
//@codingStandardsIgnoreEnd

	/**
	* Method to return the title to use for the asset table.
	*
	* @return  string
	*/
//@codingStandardsIgnoreStart
	protected function _getAssetTitle()
	{
		return $this->title;
	}
//@codingStandardsIgnoreEnd

	/**
	* Method to get the parent asset id for the record
	*
	* @param   JTable   $table  A JTable object (optional) for the asset parent
	* @param   integer  $id     The id (optional) of the content.
	*
	* @return  integer
	*/
//@codingStandardsIgnoreStart
	protected function _getAssetParentId(JTable $table = null, $id = null)
	{
		// Initialise variables.
		$assetId = null;

		// This is a Roughcheck check under a category.
		if ($this->catid) {
			// Build the query to get the asset id for the parent category.
			$query = $this->_db->getQuery(true);
			$query->select($this->_db->quoteName('asset_id'));
			$query->from($this->_db->quoteName('#__categories'));
			$query->where($this->_db->quoteName('id') . ' = ' . (int) $this->catid);

			// Get the asset id from the database.
			$this->_db->setQuery($query);
			if ($result = $this->_db->loadResult()) {
				$assetId = (int) $result;
			}
		}

		// Return the asset id.
		if ($assetId) {
			return $assetId;
		} else {
			return parent::_getAssetParentId($table, $id);
		}
	}
//@codingStandardsIgnoreEnd

	/**
	* Rule check
	*
	* @return true if valid else false
	*/
	function check()
	{
		if (trim($this->title) == '') {
			$this->setError(JText::_('COM_ROUGHCHECK_CHECK_TITLE'));
			return false;
		}

		// Verify that the alias is unique
		$table = JTable::getInstance('Check', 'Table');
		if ($table->load(
			array(
				'alias' => $this->alias
			)
		) && ($table->id != $this->id || $this->id==0)) {
			$this->setError(JText::_('COM_ROUGHCHECK_ERROR_UNIQUE_ALIAS'));
			return false;
		}

		if (trim($this->alias) == '') {
			$this->alias = $this->title;
		}
		$this->alias = JApplication::stringURLSafe($this->alias);
		if (trim(str_replace('-', '', $this->alias)) == '') {
			$this->alias = JFactory::getDate()->format('Y-m-d-H-i-s');
		}

		// clean up keywords -- eliminate extra spaces between phrases
		// and cr (\r) and lf (\n) characters from string
		if (!empty($this->metakey)) {
			// only process if not empty
			// array of characters to remove
			$bad_characters = array("\n", "\r", "\"", "<", ">");
			// remove bad characters
			$after_clean = JString::str_ireplace(
				$bad_characters, "", $this->metakey
			);
			// create array using commas as delimiter
			$keys = explode(',', $after_clean);
			$clean_keys = array();
			foreach ($keys as $key) {
				if (trim($key)) {  // ignore blank keywords
					$clean_keys[] = trim($key);
				}
			}
			// put array back together delimited by ", "
			$this->metakey = implode(", ", $clean_keys);
		}

		return true;
	}

	/**
	* Method to set the publishing state for a row or list of rows in the database
	* table.  The method respects checked out rows by other users and will attempt
	* to checkin rows that it can after adjustments are made.
	*
	* @param mixed   $pks    An optional array of primary key values to update.
	*                        If not set the instance property value is used.
	* @param integer $state  The publishing state.
	*                        eg. [0 = unpublished, 1 = published]
	* @param integer $userId The user id of the user performing the operation.
	*
	* @return boolean True on success.
	*
	* @note From JTable::publish as amended by most components s/published/state/
	*/
	public function publish($pks = null, $state = 1, $userId = 0)
	{
		// Initialise variables.
		$k = $this->_tbl_key;

		// Sanitize input.
		JArrayHelper::toInteger($pks);
		$userId = (int) $userId;
		$state  = (int) $state;

		// If there are no primary keys set check to see if the instance key is set.
		if (empty($pks)) {
			if ($this->$k) {
				$pks = array($this->$k);
			} else {
				// Nothing to set publishing state on, return false.
				$e = new JException(
					JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED')
				);
				$this->setError($e);

				return false;
			}
		}

		// Update the publishing state for rows with the given primary keys.
		$query = $this->_db->getQuery(true);
		$query->update($this->_tbl);
		$query->set('state = '.(int) $state);

		// Determine if there is checkin support for the table.
		if (property_exists($this, 'checked_out')
			|| property_exists($this, 'checked_out_time')
		) {
			$query->where('(checked_out = 0 OR checked_out = '.(int) $userId.')');
			$checkin = true;
		} else {
			$checkin = false;
		}

		// Build the WHERE clause for the primary keys.
		$query->where($k.' = '.implode(' OR '.$k.' = ', $pks));

		$this->_db->setQuery($query);

		// Check for a database error.
		if (!$this->_db->query()) {
			$e = new JException(
				JText::sprintf(
					'JLIB_DATABASE_ERROR_PUBLISH_FAILED',
					get_class($this),
					$this->_db->getErrorMsg()
				)
			);
			$this->setError($e);

			return false;
		}

		// If checkin is supported and all rows were adjusted, check them in.
		if ($checkin && (count($pks) == $this->_db->getAffectedRows())) {
			// Checkin the rows.
			foreach ($pks as $pk) {
				$this->checkin($pk);
			}
		}

		// If the JTable instance value is in the
		// list of primary keys that were set, set the instance.
		if (in_array($this->$k, $pks)) {
			$this->state = $state;
		}

		$this->setError('');
		return true;
	}

	/**
	 * Overload the store method for the Checks table.
	 *
	 * @param boolean $updateNulls Toggle whether null values should be updated.
	 *
	 * @return	boolean	True on success, false on failure.
	 */
	public function store($updateNulls = false)
	{
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();

		if (empty($this->alias)) {
			$this->alias = JApplication::stringURLSafe($table->title);
		}
		$this->title		= htmlspecialchars_decode($this->title, ENT_QUOTES);
		$this->alias		= JApplication::stringURLSafe($this->alias);

		if ($this->id) {
			// Existing item
			$this->modified		= $date->toSQL();
			$this->modified_by	= $user->get('id');
		} else {
			// New check.
			// A check created and created_by field can be set by the user,
			// so we don't touch either of these if they are set.
			if (!intval($this->created)) {
				$this->created = $date->toSQL();
			}
			if (empty($this->created_by)) {
				$this->created_by = $user->get('id');
			}
			if (empty($this->checked_out_time)) {
				$this->checked_out_time = $date->toSQL();
			}
			if (empty($this->checked_out)) {
				$this->checked_out = 0;
			}
			// Set ordering to the last item if not set
			if (empty($this->ordering)) {
				$db = $this->getDbo();
				$db->setQuery('SELECT MAX(ordering) FROM #__roughcheck_checks');
				$max = $db->loadResult();

				$this->ordering = $max+1;
			}

			if (trim($this->xreference) == '') {
				$this->xreference = RoughcheckHelper::uuid();
			}
		}

		// Increment the content version number.
		$this->version++;

		// Set the publish date to now
		if ($this->state == 1 && intval($this->publish_up) == 0) {
			$this->publish_up = $date->toSQL();
		}

		// Attempt to store the user data.
		return parent::store($updateNulls);
	}

}
