<?php
/**
* Check topic table
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checktopic.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Check topic table class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class TableChecktopic extends JTable
{

	/**
	* Constructor
	*
	* @param object &$db Database connector object
	*/
	function __construct( &$db )
	{
		parent::__construct('#__roughcheck_check_topics', 'id', $db);
	}

	/**
	* Rule check
	*
	* @return true if valid else false
	*/
	function check()
	{
		if (strlen($this->title) == 0) {
			$this->setError(JText::_('COM_ROUGHCHECK_CHECK_TITLE'));
			return false;
		}

		return true;
	}

	/**
	* Method to set the publishing state for a row or list of rows in the database
	* table.  The method respects checked out rows by other users and will attempt
	* to checkin rows that it can after adjustments are made.
	*
	* @param mixed   $pks    An optional array of primary key values to update.
	*                        If not set the instance property value is used.
	* @param integer $state  The publishing state.
	*                        eg. [0 = unpublished, 1 = published]
	* @param integer $userId The user id of the user performing the operation.
	*
	* @return boolean True on success.
	*
	* @note From JTable::publish as amended by most components s/published/state/
	*/
	public function publish($pks = null, $state = 1, $userId = 0)
	{
		// Initialise variables.
		$k = $this->_tbl_key;

		// Sanitize input.
		JArrayHelper::toInteger($pks);
		$userId = (int) $userId;
		$state  = (int) $state;

		// If there are no primary keys set check to see if the instance key is set.
		if (empty($pks)) {
			if ($this->$k) {
				$pks = array($this->$k);
			} else {
				// Nothing to set publishing state on, return false.
				$e = new JException(
					JText::_('JLIB_DATABASE_ERROR_NO_ROWS_SELECTED')
				);
				$this->setError($e);

				return false;
			}
		}

		// Update the publishing state for rows with the given primary keys.
		$query = $this->_db->getQuery(true);
		$query->update($this->_tbl);
		$query->set('state = '.(int) $state);

		// Determine if there is checkin support for the table.
		if (property_exists($this, 'checked_out')
			|| property_exists($this, 'checked_out_time')
		) {
			$query->where('(checked_out = 0 OR checked_out = '.(int) $userId.')');
			$checkin = true;
		} else {
			$checkin = false;
		}

		// Build the WHERE clause for the primary keys.
		$query->where($k.' = '.implode(' OR '.$k.' = ', $pks));

		$this->_db->setQuery($query);

		// Check for a database error.
		if (!$this->_db->query()) {
			$e = new JException(
				JText::sprintf(
					'JLIB_DATABASE_ERROR_PUBLISH_FAILED',
					get_class($this),
					$this->_db->getErrorMsg()
				)
			);
			$this->setError($e);

			return false;
		}

		// If checkin is supported and all rows were adjusted, check them in.
		if ($checkin && (count($pks) == $this->_db->getAffectedRows())) {
			// Checkin the rows.
			foreach ($pks as $pk) {
				$this->checkin($pk);
			}
		}

		// If the JTable instance value is in the
		// list of primary keys that were set, set the instance.
		if (in_array($this->$k, $pks)) {
			$this->state = $state;
		}

		$this->setError('');
		return true;
	}

	/**
	* Overload the store method for the Checks table.
	*
	* @param boolean $updateNulls Toggle whether null values should be updated.
	*
	* @return	boolean	True on success, false on failure.
	*/
	public function store($updateNulls = false)
	{
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();

		$this->title		= htmlspecialchars_decode($this->title, ENT_QUOTES);

		if ($this->id) {
			// Existing item
			$this->modified		= $date->toSQL();
			$this->modified_by	= $user->get('id');
		} else {
			// New Check topic
			if (!intval($this->created)) {
				$this->created = $date->toSQL();
			}
			if (empty($this->created_by)) {
				$this->created_by = $user->get('id');
			}
			if (empty($this->checked_out_time)) {
				$this->checked_out_time = $date->toSQL();
			}
			if (empty($this->checked_out)) {
				$this->checked_out = 0;
			}

			// Set ordering to the last item if not set
			if (empty($this->ordering)) {
				$db = $this->getDbo();
				$query = $db->getQuery(true);
				$query->select('MAX(ordering)');
				$query->from('#__roughcheck_check_topics');
				$query->where('check_id = ' . (int) $this->check_id);
				$db->setQuery($query);
				$max = $db->loadResult();

				$this->ordering = $max+1;
			}
		}

		// Attempt to store the user data.
		return parent::store($updateNulls);

	}

}
