<?php
/**
* Component to manage a Roughcheck assessment
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: default_head.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted Access');

?>
<h1><?php echo $this->escape($this->assessment->title);?></h1>
<div><?php echo $this->assessment->description;?></div>
<h2><?php echo $this->escape($this->check->title);?></h2>
<div><?php echo $this->check->description;?></div>
<?php
$matrix = array();

// Prime the summary array
foreach ($this->rewards as $i => $reward) {
	$matrix[$reward->id] = array();
	foreach ($this->risks as $j => $risk) {
		$matrix[$reward->id][$risk->id] = array(
			'positiverisk' => 0,
			'unknownrisk' => 0,
			'positivereward' => 0,
			'unknownreward' => 0,
			'negativerisk' => 0,
			'negativereward' => 0,
		);
	}
}

foreach ($this->items as $i => $item) {
	if (isset($item->response)) {
		$risk_id = $item->response_risk_detail_id;
		$reward_id = $item->response_reward_detail_id;
		if ($item->response == $item->risk_trigger) {
			$matrix[$reward_id][$risk_id]['positiverisk']++;
		} else {
			$matrix[$reward_id][$risk_id]['negativerisk']++;
		}
		if ($item->response == $item->reward_trigger) {
			$matrix[$reward_id][$risk_id]['positivereward']++;
		} else {
			$matrix[$reward_id][$risk_id]['negativereward']++;
		}
	} else {
		$risk_id = $item->question_risk_detail_id;
		$reward_id = $item->question_reward_detail_id;
		$matrix[$reward_id][$risk_id]['unknownrisk']++;
		$matrix[$reward_id][$risk_id]['unknownreward']++;
	}
}

// Start summary
echo '<h2>';
echo JText::_('COM_ROUGHCHECK_ASSESSMENTREPORT_SUMMARY');
echo '</h2>';
echo '<table class="table" style="width: auto;">';

// Risk labels
echo '<thead>';
echo '<tr>';
	echo '<th>';
	echo $this->riskprofile->report_title;
	echo '/';
	echo $this->rewardprofile->report_title;
	echo '</th>';
foreach ($this->rewards as $i => $reward) {
	echo '<th>';
	if ($reward->image > '') {
		echo '<img ';
		echo ' src="'.JURI::root() . $reward->image . '"';
		echo ' alt="'. $reward->title . ' ' . $this->rewardprofile->report_title . '"';
		echo ' title="'. $reward->title . ' ' . $this->rewardprofile->report_title . '"';
		echo '/>';
		echo '&nbsp;';
	}
	echo $reward->title;
	echo '</th>';
}
echo '</tr>';
echo '</thead>';

// Output the summary
echo '<tbody>';

// Positive results
echo '<tr>';
echo '<th colspan="'.(count($this->risks) + 1) .'">';
if ($this->riskprofile->positive == $this->rewardprofile->positive) {
	echo $this->riskprofile->positive;
} else {
	echo $this->riskprofile->positive . ' / ' . $this->rewardprofile->positive;
}
echo '</th>';
echo '</tr>';

foreach ($this->risks as $j => $risk) {
	$showrow = 0;
	foreach ($this->rewards as $i => $reward) {
		if ($matrix[$reward->id][$risk->id]['positiverisk']
			|| $matrix[$reward->id][$risk->id]['positivereward']) {
			$showrow = 1;
		}
	}
	if ($showrow) {
	echo '<tr class="row' . ($j % 2) .'">';
	echo '<th>';
	if ($risk->image > '') {
		echo '<img ';
		echo ' src="' .JURI::root() . $risk->image . '"';
		echo ' alt="' . $this->riskprofile->report_title . ' ' . $risk->title . '"';
		echo ' title="' . $this->riskprofile->report_title . ' ' . $risk->title . '"';
		echo '/>';
		echo '&nbsp;';
	}
	echo $risk->title;
	echo '</th>';
	foreach ($this->rewards as $i => $reward) {
		echo '<td class="risk">';
		if ($matrix[$reward->id][$risk->id]['positivereward'] == 0
			&& $matrix[$reward->id][$risk->id]['positiverisk'] == 0
		) {
			echo '-';
		} else {
			echo '<span title="';
			echo $this->riskprofile->report_title . ' ' . $this->riskprofile->positive;
			echo ': ';
			echo $risk->title . '"';
			echo '>';
			echo $matrix[$reward->id][$risk->id]['positiverisk'];
			echo '</span> / <span title="';
			echo $this->rewardprofile->report_title . ' ' . $this->rewardprofile->positive;
			echo ': ';
			echo $reward->title . '"';
			echo '>';
			echo $matrix[$reward->id][$risk->id]['positivereward'];
			echo '</span>';
		}
		echo '</td>';
	}
	echo '</tr>';
	}
}

// Unknown results
echo '<tr>';
echo '<th colspan="'.(count($this->risks) + 1).'">';
if ($this->riskprofile->unknown == $this->rewardprofile->unknown) {
	echo $this->riskprofile->unknown;
} else {
	echo $this->riskprofile->unknown . ' / ' . $this->rewardprofile->unknown;
}
echo '</th>';
echo '</tr>';
foreach ($this->risks as $j => $risk) {
	$showrow = 0;
	foreach ($this->rewards as $i => $reward) {
		if ($matrix[$reward->id][$risk->id]['unknownrisk']
			|| $matrix[$reward->id][$risk->id]['unknownreward']) {
			$showrow = 1;
		}
	}
	if ($showrow) {
	echo '<tr class="row' . ($j % 2) .'">';
	echo '<th>';
	if ($risk->image > '') {
		echo '<img ';
		echo ' src="'.JURI::root() . $risk->image . '"';
		echo ' alt="'. $risk->title . ' ' . $this->riskprofile->report_title . '"';
		echo ' title="'. $risk->title . ' ' . $this->riskprofile->report_title . '"';
		echo '/>';
		echo '&nbsp;';
	}
	echo $risk->title;
	echo '</th>';
	foreach ($this->rewards as $i => $reward) {
		echo '<td class="risk">';
		if ($matrix[$reward->id][$risk->id]['unknownreward'] == 0
			&& $matrix[$reward->id][$risk->id]['unknownrisk'] == 0
		) {
			echo '-';
		} else {
			echo '<span title="';
			echo $this->riskprofile->report_title . ' ' . $this->riskprofile->unknown;
			echo ': ';
			echo $risk->title . '"';
			echo '>';
			echo $matrix[$reward->id][$risk->id]['unknownrisk'];
			echo '</span> / <span title="';
			echo $this->rewardprofile->report_title . ' ' . $this->rewardprofile->unknown;
			echo ': ';
			echo $reward->title . '"';
			echo '>';
			echo $matrix[$reward->id][$risk->id]['unknownreward'];
			echo '</span>';
		}
		echo '</td>';
	}
	echo '</tr>';
	}
}

// Negative results
echo '<tr>';
echo '<th colspan="'.(count($this->risks) + 1).'">';
if ($this->riskprofile->negative == $this->rewardprofile->negative) {
	echo $this->riskprofile->negative;
} else {
	echo $this->riskprofile->negative . ' / ' . $this->rewardprofile->negative;
}
echo '</th>';
echo '</tr>';

foreach ($this->risks as $j => $risk) {
	$showrow = 0;
	foreach ($this->rewards as $i => $reward) {
		if ($matrix[$reward->id][$risk->id]['negativerisk']
			|| $matrix[$reward->id][$risk->id]['negativereward']) {
			$showrow = 1;
		}
	}
	if ($showrow) {
	echo '<tr class="row' . ($j % 2) .'">';
	echo '<th>';
	if ($risk->image > '') {
		echo '<img ';
		echo ' src="' .JURI::root() . $risk->image . '"';
		echo ' alt="' . ' ' . $this->riskprofile->report_title . $risk->title . '"';
		echo ' title="' . $this->riskprofile->report_title . ' ' . $risk->title . '"';
		echo '/>';
		echo '&nbsp;';
	}
	echo $risk->title;
	echo '</th>';
	foreach ($this->rewards as $i => $reward) {
		echo '<td class="risk">';
		if ($matrix[$reward->id][$risk->id]['negativereward'] == 0
			&& $matrix[$reward->id][$risk->id]['negativerisk'] == 0
		) {
			echo '-';
		} else {
			echo '<span title="';
			echo $this->riskprofile->report_title .  ' ' . $this->riskprofile->negative;
			echo ': ';
			echo $risk->title . '"';
			echo '>';
			echo $matrix[$reward->id][$risk->id]['negativerisk'];
			echo '</span> / <span title="';
			echo $this->rewardprofile->report_title . ' ' . $this->rewardprofile->negative;
			echo ': ';
			echo $reward->title . '"';
			echo '>';
			echo $matrix[$reward->id][$risk->id]['negativereward'];
			echo '</span>';
		}
		echo '</td>';
	}
	echo '</tr>';
	}
}
echo '</tbody>';
echo '</table>';
