<?php
/**
* Checkquestions view
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: view.html.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Checkquestions view class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckViewCheckquestions extends JViewLegacy
{
	protected $items;
	protected $check;
	protected $hastopics;
	protected $topics;
	protected $state;
	protected $pagination;
	protected $sidebar;

	/**
	* Display method for Check questions
	*
	* @param string $tpl Template to display
	*
	* @return void
	**/
	function display($tpl = null)
	{
		// Get data from the model
		$this->check = $this->get('Check');
		$this->items = $this->get('Items');
		$this->hastopics = $this->get('HasTopics');
		$this->topics = $this->get('Topics');
		$this->state = $this->get('State');
		$this->pagination = $this->get('Pagination');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			foreach ($errors as $error) {
				JLog::add($error, JLog::ERROR, COM_ROUGHCHECK);
			}
			throw new Exception('An error occured');
			return false;
		}

		$this->addToolBar();
		$this->sidebar = JHtmlSidebar::render();

		parent::display($tpl);
	}

	/**
	* Setting the toolbar
	*
	* @return void
	*/
	protected function addToolbar()
	{

		JToolBarHelper::title(
			JText::_('COM_ROUGHCHECK_CHECKQUESTIONS_HEADING'), 'article'
		);

		$state	= $this->get('State');
		$canDo	= RoughcheckHelper::getActions($state->get('filter.category_id'));
		$user	= JFactory::getUser();

		if ($this->hastopics) {
			JToolBarHelper::addNew('checkquestion.add', 'JTOOLBAR_NEW');
		}
		if ($canDo->get('core.edit')) {
			JToolBarHelper::editList(
				'checkquestion.edit',
				'JTOOLBAR_EDIT'
			);
			JToolBarHelper::custom(
				'checkquestions.checktopics',
				'edit',
				'',
				'COM_ROUGHCHECK_HEADING_TOPICS',
				false
			);
			JToolBarHelper::divider();
		}
		if ($canDo->get('core.edit.state')) {
			JToolBarHelper::publish(
				'checkquestion.publish',
				'JTOOLBAR_PUBLISH',
				true
			);
			JToolBarHelper::unpublish(
				'checkquestion.unpublish',
				'JTOOLBAR_UNPUBLISH',
				true
			);
			JToolBarHelper::divider();
			JToolBarHelper::archiveList('checkquestion.archive');
			JToolBarHelper::checkin('checkquestion.checkin');
		}

		if ($state->get('filter.state') == -2 && $canDo->get('core.delete')) {
			JToolBarHelper::deleteList(
				'', 'checkquestions.delete', 'JTOOLBAR_EMPTY_TRASH'
			);
			JToolBarHelper::divider();
		} else if ($canDo->get('core.edit.state')) {
			JToolBarHelper::trash('checkquestions.trash');
			JToolBarHelper::divider();
		}

        JToolBarHelper::custom(
            'checkquestions.cancel', 'back', '', 'JTOOLBAR_BACK', false
        );
		JToolBarHelper::divider();

		JToolBarHelper::help('index', true);

		JHtmlSidebar::setAction('index.php?option=com_roughcheck&view=checkquestions');

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_PUBLISHED'),
			'filter_published',
			JHtml::_('select.options', JHtml::_('jgrid.publishedOptions'), 'value', 'text', $this->state->get('filter.published'), true)
		);

		JHtmlSidebar::addFilter(
			JText::_('COM_ROUGHCHECK_SELECT_TOPIC'),
			'filter_access',
			JHtml::_('select.options', $this->topics, 'value', 'text', $this->state->get('filter.topic_id'))
		);

	}

	/**
	* Returns an array of fields the table can be sorted by
	*
	* @return  array  Array containing the field name to sort by as the key and display text as value
	*/
	protected function getSortFields()
	{
		return array(
			'a.ordering' => JText::_('JGRID_HEADING_ORDERING'),
			'a.state' => JText::_('JSTATUS'),
			'a.title' => JText::_('JGLOBAL_TITLE'),
			'a.id' => JText::_('JGRID_HEADING_ID'),
		);
	}
}
