<?php
/**
* Checks view
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: view.html.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Checks view class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckViewChecks extends JViewLegacy
{
	protected $items;
	protected $state;
	protected $pagination;
	protected $sidebar;

	/**
	* Display method for Checks
	*
	* @param string $tpl Template to display
	*
	* @return void
	**/
	function display($tpl = null)
	{
		// Get data from the model
		$this->items = $this->get('Items');
		$this->state = $this->get('State');
		$this->pagination = $this->get('Pagination');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			foreach ($errors as $error) {
				JLog::add($error, JLog::ERROR, COM_ROUGHCHECK);
			}
			throw new Exception('An error occured');
			return false;
		}

		// We don't need toolbar in the modal window.
		if ($this->getLayout() !== 'modal')
		{
			$this->addToolbar();
			$this->sidebar = JHtmlSidebar::render();
		}

		parent::display($tpl);
	}

	/**
	* Setting the toolbar
	*
	* @return void
	*/
	protected function addToolbar()
	{

		JToolBarHelper::title(
			JText::_('COM_ROUGHCHECK_CHECKS_HEADING'), 'article'
		);

		$state	= $this->get('State');
		$canDo	= RoughcheckHelper::getActions($state->get('filter.category_id'));
		$user	= JFactory::getUser();

		if (count(
			$user->getAuthorisedCategories(
				'com_roughcheck', 'core.create'
			)
		) > 0
		) {
			JToolBarHelper::addNew('check.add', 'JTOOLBAR_NEW');
		}
		if ($canDo->get('core.edit')) {
			JToolBarHelper::editList('check.edit', 'JTOOLBAR_EDIT');
			JToolBarHelper::editList(
				'checks.checktopics',
				'COM_ROUGHCHECK_HEADING_TOPICS'
			);
			JToolBarHelper::editList(
				'checks.checkquestions',
				'COM_ROUGHCHECK_HEADING_QUESTIONS'
			);
			JToolBarHelper::divider();
		}
		if ($canDo->get('core.edit.state')) {
			JToolBarHelper::publish('check.publish', 'JTOOLBAR_PUBLISH', true);
			JToolBarHelper::unpublish('check.unpublish', 'JTOOLBAR_UNPUBLISH', true);
			JToolBarHelper::divider();

			JToolBarHelper::archiveList('check.archive');
			JToolBarHelper::checkin('check.checkin');
		}

		if ($state->get('filter.state') == -2 && $canDo->get('core.delete')) {
			JToolBarHelper::deleteList('', 'checks.delete', 'JTOOLBAR_EMPTY_TRASH');
			JToolBarHelper::divider();
		} else if ($canDo->get('core.edit.state')) {
			JToolBarHelper::trash('checks.trash');
			JToolBarHelper::divider();
		}

		if ($canDo->get('core.admin')) {
			JToolBarHelper::preferences('com_roughcheck');
			JToolBarHelper::divider();
		}

		JToolBarHelper::help('checks', true);

		JHtmlSidebar::setAction('index.php?option=com_roughcheck&view=checks');

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_PUBLISHED'),
			'filter_published',
			JHtml::_('select.options', JHtml::_('jgrid.publishedOptions'), 'value', 'text', $this->state->get('filter.state'), true)
		);

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_CATEGORY'),
			'filter_category_id',
			JHtml::_('select.options', JHtml::_('category.options', 'com_roughcheck'), 'value', 'text', $this->state->get('filter.category_id'))
		);

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_ACCESS'),
			'filter_access',
			JHtml::_('select.options', JHtml::_('access.assetgroups'), 'value', 'text', $this->state->get('filter.access'))
		);

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_LANGUAGE'),
			'filter_language',
			JHtml::_('select.options', JHtml::_('contentlanguage.existing', true, true), 'value', 'text', $this->state->get('filter.language'))
		);

	}

	/**
	* Returns an array of fields the table can be sorted by
	*
	* @return  array  Array containing the field name to sort by as the key and display text as value
	*/
	protected function getSortFields()
	{
		return array(
			'a.ordering' => JText::_('JGRID_HEADING_ORDERING'),
			'a.state' => JText::_('JSTATUS'),
			'a.title' => JText::_('JGLOBAL_TITLE'),
			'category_title' => JText::_('JCATEGORY'),
			'a.access' => JText::_('JGRID_HEADING_ACCESS'),
			'a.language' => JText::_('JGRID_HEADING_LANGUAGE'),
			'a.id' => JText::_('JGRID_HEADING_ID'),
		);
	}
}
