<?php
/**
* Riskdetails view
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: view.html.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Riskdetails view class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckViewRiskdetails extends JViewLegacy
{
	protected $items;
	protected $risk;
	protected $state;
	protected $pagination;
	protected $sidebar;

	/**
	* Display method for Checks
	*
	* @param string $tpl Template to display
	*
	* @return void
	**/
	function display($tpl = null)
	{
		// Get data from the model
		$this->items = $this->get('Items');
		$this->risk = $this->get('Risk');
		$this->state = $this->get('State');
		$this->pagination = $this->get('Pagination');

		// Check for errors.
		if (count($errors = $this->get('Errors'))) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			foreach ($errors as $error) {
				JLog::add($error, JLog::ERROR, COM_ROUGHCHECK);
			}
			throw new Exception('An error occured');
			return false;
		}

		JFactory::getApplication()->input->set('hidemainmenu', true);
		$this->addToolBar();
		$this->sidebar = JHtmlSidebar::render();

		parent::display($tpl);
	}

	/**
	* Setting the toolbar
	*
	* @return void
	*/
	protected function addToolbar()
	{

		JToolBarHelper::title(
			JText::_('COM_ROUGHCHECK_RISKDETAILS_HEADING'),
			'article'
		);

		$state	= $this->get('State');
		$canDo	= RoughcheckHelper::getActions();
		$user	= JFactory::getUser();

		if ($canDo->get('core.create')) {
			JToolBarHelper::addNew('riskdetail.add', 'JTOOLBAR_NEW');
		}
		if ($canDo->get('core.edit')) {
			JToolBarHelper::editList('riskdetail.edit', 'JTOOLBAR_EDIT');
			JToolBarHelper::divider();
		}
		if ($canDo->get('core.edit.state')) {
			JToolBarHelper::publish('riskdetails.publish', 'JTOOLBAR_PUBLISH', true);
			JToolBarHelper::unpublish(
				'riskdetails.unpublish', 'JTOOLBAR_UNPUBLISH', true
			);

			JToolBarHelper::divider();
			JToolBarHelper::archiveList('riskdetails.archive');
			JToolBarHelper::checkin('riskdetails.checkin');
		}

		if ($state->get('filter.state') == -2 && $canDo->get('core.delete')) {
			JToolBarHelper::deleteList(
				'', 'riskdetails.delete', 'JTOOLBAR_EMPTY_TRASH'
			);
			JToolBarHelper::divider();
		} else if ($canDo->get('core.edit.state')) {
			JToolBarHelper::trash('riskdetails.trash');
			JToolBarHelper::divider();
		}

		$href = JRoute::_('index.php?option=com_roughcheck&view=risks');
		JToolBarHelper::back('JTOOLBAR_BACK', $href);
		JToolBarHelper::divider();

		JToolBarHelper::help('risks', true);

		$action = 'index.php?option=com_roughcheck&view=riskdetails';
		$action .= '&id='.$this->risk->id;
		JHtmlSidebar::setAction($action);

		JHtmlSidebar::addFilter(
			JText::_('JOPTION_SELECT_PUBLISHED'),
			'filter_published',
			JHtml::_('select.options', JHtml::_('jgrid.publishedOptions'), 'value', 'text', $this->state->get('filter.state'), true)
		);
	}

	/**
	* Returns an array of fields the table can be sorted by
	*
	* @return  array  Array containing the field name to sort by as the key and display text as value
	*/
	protected function getSortFields()
	{
		return array(
			'a.ordering' => JText::_('JGRID_HEADING_ORDERING'),
			'a.state' => JText::_('JSTATUS'),
			'a.title' => JText::_('JGLOBAL_TITLE'),
			'a.id' => JText::_('JGRID_HEADING_ID'),
		);
	}
}
