<?php
/**
* Assessment controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessment.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment controller
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckControllerAssessment extends JControllerForm
{
	/**
	* Saved id
	*/
	private $_id;

	/**
	* Method override to check if you can add a new record.
	*
	* @param array $data An array of input data.
	*
	* @return boolean
	*/
	protected function allowAdd($data = array())
	{
		// Initialise variables.
		$user = JFactory::getUser();

		$model = $this->getModel();
		$table = $model->getTable('Check');
		if (array_key_exists('check_id', $data)) {
			JLog::add(
				'data[check_id]: ' . $data['check_id'],
				JLog::DEBUG, COM_ROUGHCHECK
			);
			$table->load($data['check_id']);
		} else {
			$app = JFactory::getApplication();
			$check_id = $app->getUserState('com_roughcheck.check.id');
			if ($check_id) {
				$table->load($check_id);
			}
		}
		$checkId = $table->id;
		unset($table);

		if ($checkId) {
			// Specific Roughcheck check
			JLog::add(
				$this->option . '.check.' . $checkId,
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return $user->authorise(
				'assessment.create',
				$this->option . '.check.' . $checkId
			);
		} else {
			// Unspecific Roughcheck check
			JLog::add(
				$this->option . '.check.' . $checkId,
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return $user->authorise(
				'assessment.create',
				$this->option
			);
		}
	}

	/**
	* Method to check if you can edit an existing record.
	*
	* @param array  $data An array of input data.
	* @param string $key  The name of the key for the primary key.
	*
	* @return  boolean
	*/
	protected function allowEdit($data = array(), $key = 'id')
	{
		// Initialise variables.
		$recordId = (int) isset($data[$key]) ? $data[$key] : 0;

		$model = $this->getModel();
		$table = $model->getTable();
		if ($recordId) {
			$table->load($recordId);
		}

		$user = JFactory::getUser();
		$userId = $user->get('id');
		$asset	= 'com_roughcheck.assessment.' . $recordId;
		$app = JFactory::getApplication();
		$userXref = $app->getUserState($asset);
		if ($user->authorise('assessment.edit', $asset)) {
			// User is allowed access
			JLog::add('Access via assessment.edit', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userId)
			&& $user->authorise('assessment.edit.own', $asset)
			&& $userId == $table->created_by
		) {
			// User is allowed access to own assessment
			JLog::add('Access via assessment.edit.own', JLog::DEBUG, COM_ROUGHCHECK);
		} elseif (
			!empty($userXref)
			&& $userXref == $table->xreference
			&& $user->authorise('assessment.edit.xref', $asset)
		) {
			// User is allowed access via xreference
			JLog::add('Access via xref', JLog::DEBUG, COM_ROUGHCHECK);
		} else {
			// User is not allowed access to this assessment
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add('No access to: ' . $asset, JLog::ERROR, COM_ROUGHCHECK);

			$route = 'index.php?option='.$this->option;
			$route .= '&view=assessment';
			$route .= '&layout=xref';
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			$this->setRedirect(JRoute::_($route, false));
 			return false;
		}
		return true;
	}

	/**
	* Function that allows this child controller access to model data
	* after the data has been saved.
	*
	* @param RoughcheckModelAssessment &$model    The data model object.
	* @param array                     $validData The validated data.
	*
	* @return  void
	*/
	protected function postSaveHook(JModelLegacy $model, $validData = array())
	{
		$this->_id = $model->getState($this->context . '.id');
	}

	/**
	* Method to save a record, then forward to the assessments.
	*
	* @param string $key    The name of the primary key of the URL variable.
	* @param string $urlVar The name of the URL variable if different from the
	*                       primary key (sometimes required to avoid router
	*                       collisions).
	*
	* @return	Boolean	True if successful, false otherwise.
	*/
	public function save($key = null, $urlVar = null)
	{
		$success = parent::save($key, $urlVar);

		$task = $this->getTask();

		if ($success && $task == 'save') {
			$app = JFactory::getApplication();

			$clientwidth = $app->input->getInt('com_roughcheck_clientwidth', 0);
			if ($clientwidth) {
				$app->setUserState('com_roughcheck.clientwidth', $clientwidth);
			}

			$route = 'index.php?option='.$this->option;
			$route .= '&task=assessments.assessmentquestions';
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			if ($this->_id) {
				$route .= '&id=' . $this->_id;
			}
			$this->setRedirect(JRoute::_($route, false));
		}

		return $success;
	}

	/**
	* Method to add a new record.
	*
	* @return  mixed  True if the record can be added, a JError object if not.
	*/
	public function add()
	{
		$app = JFactory::getApplication();
		$check_id = $app->input->getInt('check_id', 0);
		$app->setUserState('com_roughcheck.check.id', $check_id);

		$success = parent::add();

		return $success;
	}

	/**
	* Method to go to the report
	*
	* @return void
	*/
	public function assessmentreport()
	{
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

		$app = JFactory::getApplication();
		$assessment_id = $app->input->getInt('assessment_id', 0);
		if (!$assessment_id) {
			$assessment_id = $app->input->getInt('id', 0);
		}

		$this->setRedirect(
			JRoute::_(
				'index.php?option=' . $this->option
				. '&view=assessmentreport'
				. '&id='.$assessment_id,
				false
			)
		);

		return true;
	}

	/**
	* Method to cancel an edit.
	*
	* @param string $key The name of the primary key of the URL variable.
	*
	* @return boolean True if access level checks pass, false otherwise.
	*/
	public function cancel($key = null)
	{
		$return = parent::cancel($key);
		if ($return) {
			$user = JFactory::getUser();
			$return_route = 'index.php';
			if (!$user->guest) {
				$return_route = 'index.php?option=' . $this->option;
				$return_route .= '&view=assessments';
				$app = JFactory::getApplication();
				$Itemid = $app->input->getInt('Itemid', 0);
				if ($Itemid) {
					$return_route .= '&Itemid=' . $Itemid;
				}
			}
			$this->setRedirect(JRoute::_($return_route, false));
		}
		return $return;
	}

	/**
	* Method to add xref token
	*
	* @return	Boolean	True
	*/
	public function addxref()
	{
		$app = JFactory::getApplication();
		$tmpl   = $app->input->getCmd('tmpl');
		$layout = 'xref';
		$route = 'index.php?option=' . $this->option . '&view=assessment';

		// Setup redirect info.
		if ($tmpl) {
			$route .= '&tmpl=' . $tmpl;
		}

		if ($layout) {
			$route .= '&layout=' . $layout;
		}

		$this->setRedirect(JRoute::_($route, false));

		return true;
	}

	/**
	* Method to save an xref token, then forward to the assessment.
	*
	* @return	Boolean	True if successful, false otherwise.
	*/
	public function xrefsave()
	{
		// Check for request forgeries.
		JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));
		$app = JFactory::getApplication();
		$model = $this->getModel();
		$table = $model->getTable();
		$jform  = $this->input->post->get('jform', array(), 'array');
		$xref  = $jform['xreference'];
		// Check that the seperator string exists and is not the first character
		$isxref = strpos($xref, '-');
		if ($xref && $isxref) {
			list($recordId, $xreference) = explode('-', $xref, 2);
			$recordId = (int)$recordId;
		} else {
			$route = 'index.php?option='.$this->option;
			$route .= '&view=assessment';
			$route .= '&layout=xref';
			$msg = JText::_('COM_ROUGHCHECK_ASSESSMENT_AUTHORIZATION_REQUIRED');
			$this->setRedirect(JRoute::_($route, false), $msg);
			return true;
		}
		if ($recordId) {
			$table->load($recordId);
		} else {
			JLog::add(__METHOD__ . '()', JLog::DEBUG, COM_ROUGHCHECK);
			JLog::add(
				'Invalid xref: ' . $xref,
				JLog::DEBUG, COM_ROUGHCHECK
			);
			return true;
		}

		if ($table->id
			&& ($table->xreference > '')
			&& ($table->xreference == $xreference)
		) {
			$app->setUserState(
				'com_roughcheck.assessment.' . $table->id, $xreference
			);
			// Auto checkin in case where other user timed out
			$table->checkIn();
			$success = true;
		} else {
			$success = false;
		}

		$route = 'index.php?option='.$this->option;
		if ($success) {
			$route .= '&task=assessment.edit';
			$route .= '&layout=edit';
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			if ($table->id) {
				$route .= '&id=' . $table->id;
			}
			$this->setRedirect(JRoute::_($route, false));
		} else {
			$route .= '&task=assessment.addxref';
			$tmpl   = $app->input->getCmd('tmpl');
			if ($tmpl) {
				$route .= '&tmpl=' . $tmpl;
			}
			if ($this->_id) {
				$route .= '&id=' . $this->_id;
			}
			$msg = JText::_('COM_ROUGHCHECK_ASSESSMENT_AUTHORIZATION_REQUIRED');
			$this->setRedirect(JRoute::_($route, false), $msg);
		}

		return $success;
	}

	/**
	* Method to cancel adding an xref.
	*
	* @return boolean True
	*/
	public function xrefcancel()
	{
		$app = JFactory::getApplication();
		$return_route = 'index.php?option=' . $this->option . '&view=check';
		$return_route .= '&id=' . $app->input->getInt('id', 0);
		$return_route .= '&Itemid=' . $app->input->getInt('Itemid', 0);
		$this->setRedirect(JRoute::_($return_route, false));
		return true;
	}

}
