<?php
/**
* Assessments model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessments.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessments model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelAssessments extends JModelList
{

	/**
	* Constructor
	*
	* @param array $config An optional associative array of configuration settings.
	*
	* @see   JController
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'a.id',
				'a.title',
				'category_title',
				'a.state',
				'ck.access',
				'ck.language',
				);
		}

		parent::__construct($config);
	}

	/**
	* Method to auto-populate the model state.
	*
	* This method should only be called once per instantiation and is designed
	* to be called on the first call to the getState() method unless the model
	* configuration flag to ignore the request is set.
	*
	* Note. Calling getState in this method will result in recursion.
	*
	* @param string $ordering  An optional ordering field.
	* @param string $direction An optional direction (asc|desc).
	*
	* @return  void
	*/
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest(
			$this->context.'.filter.search', 'filter_search'
		);
		$this->setState('filter.search', $search);

		$accessId = $this->getUserStateFromRequest(
			$this->context.'.filter.access', 'filter_access', null, 'int'
		);
		$this->setState('filter.access', $accessId);

		$published = $this->getUserStateFromRequest(
			$this->context.'.filter.state', 'filter_published', '', 'string'
		);
		$this->setState('filter.state', $published);

		$categoryId = $this->getUserStateFromRequest(
			$this->context.'.filter.category_id', 'filter_category_id', ''
		);
		$this->setState('filter.category_id', $categoryId);

		$language = $this->getUserStateFromRequest(
			$this->context.'.filter.language', 'filter_language', ''
		);
		$this->setState('filter.language', $language);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_roughcheck');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('a.title', 'asc');
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id');
		$query->select('a.check_id');
		$query->select('a.title, ck.catid');
		$query->select('a.user_id');
		$query->select('a.state');
		$query->select('a.publish_up');
		$query->select('a.publish_down');
		$query->select('a.modified, a.modified_by');
		$query->select('a.created, a.created_by');
		$query->select('a.checked_out, a.checked_out_time');
		$query->select(
			' ( select count(*)'
			. ' from   #__roughcheck_check_questions q'
			. ' where  q.check_id = a.check_id'
			.') AS countof_questions'
		);
		$query->select(
			' ( select count(*)'
			. ' from   #__roughcheck_assessment_responses w'
			. ' where  w.assessment_id = a.id'
			.') AS countof_responses'
		);
		$query->from('#__roughcheck_assessments AS a');

		// Join the Check table
		$query->select('ck.title AS check_title');
		$query->join('INNER', '#__roughcheck_checks AS ck ON ck.id = a.check_id');

		// Join over the language
		$query->select('ck.language AS language');
		$query->select('l.title AS language_title');
		$query->join('LEFT', '#__languages AS l ON l.lang_code = ck.language');

		// Join over the users for the checked out user.
		$query->select('ue.name AS editor');
		$query->join('LEFT', '#__users AS ue ON ue.id=a.checked_out');

		// Join over the users for the checked out user.
		$query->select('uc.name AS creator');
		$query->join('INNER', '#__users AS uc ON uc.id=a.created_by');
		$user = JFactory::getUser();
		$query->where('a.created_by  > 0');
		$query->where('uc.id = ' . $user->id);

		// Join over the asset groups.
		$query->select('ag.title AS access_level');
		$query->join('LEFT', '#__viewlevels AS ag ON ag.id = ck.access');

		// Join over the categories.
		$query->select('c.title AS category_title');
		$query->join('LEFT', '#__categories AS c ON c.id = ck.catid');

		// Filter by access level.
		if ($access = $this->getState('filter.access')) {
			$query->where('ck.access = '.(int) $access);
		}

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = '.(int) $published);
		} elseif ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

		// Filter by category.
		$categoryId = $this->getState('filter.category_id');
		if (is_numeric($categoryId)) {
			$query->where('ck.catid = '.(int) $categoryId);
		}

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where(
					'(a.title LIKE ' . $search
					.' OR a.xreference LIKE ' . $search . ')'
				);
			}
		}

		// Filter on the language.
		if ($language = $this->getState('filter.language')) {
			$query->where('ck.language = ' . $db->quote($language));
		}

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'a.title');
		$orderDirn	= $this->state->get('list.direction', 'asc');
		$query->order($db->escape($orderCol . ' ' . $orderDirn));

		return $query;
	}

}
