<?php
/**
* Checkhelps model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: checkhelps.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Checkhelps model
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class RoughcheckModelCheckhelps extends JModelList
{
	/**
	* Constructor
	*
	* @param array $config An optional associative array of configuration settings.
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields'])) {
			$config['filter_fields'] = array(
				'id', 'a.id',
				'title', 'a.title',
				'description', 'a.description',
				'checked_out', 'a.checked_out',
				'checked_out_time', 'a.checked_out_time',
				'ordering', 'a.ordering',
				'help_type', 'a.help_type',
				'created', 'a.created',
				'created_by', 'a.created_by',
				);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * This method should only be called once per instantiation and is designed
	 * to be called on the first call to the getState() method unless the model
	 * configuration flag to ignore the request is set.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param string $ordering  An optional ordering field.
	 * @param string $direction An optional direction (asc|desc).
	 *
	 * @return  void
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $this->getUserStateFromRequest(
			$this->context.'.filter.search', 'filter_search'
		);
		$this->setState('filter.search', $search);

		$accessId = $this->getUserStateFromRequest(
			$this->context.'.filter.access', 'filter_access', null, 'int'
		);
		$this->setState('filter.access', $accessId);

		$published = $this->getUserStateFromRequest(
			$this->context.'.filter.state', 'filter_published', '', 'string'
		);
		$this->setState('filter.state', $published);

		$categoryId = $this->getUserStateFromRequest(
			$this->context.'.filter.category_id', 'filter_category_id', ''
		);
		$this->setState('filter.category_id', $categoryId);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_roughcheck');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('a.title', 'asc');
	}

	/**
	* Returns list query
	*
	* @return string sql list query
	*/
	protected function getListQuery()
	{
		$db = JFactory::getDBO();
		$query = $db->getQuery(true);
		$query->select('a.id');
		$query->select('a.question_id');
		$query->select('a.help_type_id');
		$query->select('a.ordering');
		$query->select('a.title');
		$query->select('a.state');
		$query->select('a.publish_up, a.publish_down');
		$query->select('a.checked_out, a.checked_out_time');
		$query->select('a.created, a.created_by');
		$query->select('a.modified, a.modified_by');
		$query->select('a.description');
		$query->from($db->quoteName('#__roughcheck_question_help').' AS a');

		$query->select('ht.title as help_type');
		$query->join(
			'INNER',
			$db->quoteName('#__roughcheck_help_types')
			. ' AS ht ON ht.id=a.help_type_id'
		);

		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join(
			'LEFT',
			$db->quoteName('#__users') . ' AS uc ON uc.id=a.checked_out'
		);

		$query->where('a.state = 1');

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->escape($search, true).'%');
				$query->where('a.title LIKE ' . $search);
			}
		}

		$question = $this->getQuestion();
		if (!$question->id) {
			JLog::add(__METHOD__ . '()', JLog::ERROR, COM_ROUGHCHECK);
			JLog::add(
				'Listing Question help without question_id',
				JLog::ERROR, COM_ROUGHCHECK
			);
		}
		$query->where('a.question_id = ' . (int)$question->id);

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering', 'ordering');
		$orderDirn	= $this->state->get('list.direction', 'asc');
		if ($orderCol == 'a.ordering' || $orderCol == 'category_title') {
			$orderCol = 'c.title ' . $orderDirn . ', a.ordering';
		}

		$query->order('ht.ordering');
		$query->order($db->escape($orderCol . ' ' . $orderDirn));

		return $query;
	}

	/**
	* Method to get an array of data items.
	*
	* @return mixed An array of data items on success, false on failure.
	*/
	public function getCheck()
	{
		$app = JFactory::getApplication();
		$id = $app->input->getInt('id', 0);
		$question = $this->getTable('checkquestion');
		$question->load($id);
		$check = $this->getTable('check');
		$check->load($question->check_id);

		return $check;
	}

	/**
	* Method to get an array of data items.
	*
	* @return mixed An array of data items on success, false on failure.
	*/
	public function getQuestion()
	{
		$app = JFactory::getApplication();
		$id = $app->input->getInt('id', 0);
		$table = $this->getTable('checkquestion');
		$table->load($id);
		
		return $table;
	}
}
