<?php
/**
* Component to manage Roughcheck assessments
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: router.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Routing class from com_roughcheck
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @license    GNU General Public License version 3 or later; see LICENSE.txt
* @link       http://p-o.co.uk/
*/
class RoughcheckRouter extends JComponentRouterBase
{
    /**
    * Build the route for the com_roughcheck component
    *
    * @param array &$query An array of URL arguments
    *
    * @return array The URL arguments to use to assemble the subsequent URL.
    */
    public function build(&$query)
    {
        $segments = array();

        // get a menu item based on Itemid or currently active
        $app        = JFactory::getApplication();
        $menu       = $app->getMenu();
        $params     = JComponentHelper::getParams('com_roughcheck');
        $advanced   = $params->get('sef_advanced_link', 0);

        // we need a menu item.  Either the one specified in the query, or the current active one if none specified
        if (empty($query['Itemid']))
        {
            $menuItem = $menu->getActive();
            $menuItemGiven = false;
        }
        else
        {
            $menuItem = $menu->getItem($query['Itemid']);
            $menuItemGiven = true;
        }

        // check again
        if ($menuItemGiven && isset($menuItem) && $menuItem->component != 'com_roughcheck')
        {
            $menuItemGiven = false;
            unset($query['Itemid']);
        }

        // are we dealing with a check or category that is attached to a menu item?
        if (($menuItem instanceof stdClass)
            && isset($query['view'])
            && $menuItem->query['view'] == $query['view']
            && isset($query['id'])
            && isset($menuItem->query['id'])
            && $menuItem->query['id'] == (int) $query['id']
        ){
            unset($query['view']);

            if (isset($query['catid']))
            {
                unset($query['catid']);
            }

            if (isset($query['layout']))
            {
                unset($query['layout']);
            }

            unset($query['id']);

            JLog::add('returning segments', JLog::DEBUG, 'com_roughcheck');
            return $segments;
        }

        $mView  = (empty($menuItem->query['view'])) ? null : $menuItem->query['view'];
        $mCatid = (empty($menuItem->query['catid'])) ? null : $menuItem->query['catid'];
        $mId    = (empty($menuItem->query['id'])) ? null : $menuItem->query['id'];
        $mLayout= (empty($menuItem->query['layout'])) ? null : $menuItem->query['layout'];

        // Menu view is an assessment
        if (isset($query['view'])
            && ($mView == $query['view'])
        ) {
            JLog::add('Stuff', JLog::DEBUG, 'com_roughcheck');
            if (isset($query['layout'])
                && ($mLayout == $query['layout'])
                && ! isset($query['id'])
            ) {
                unset($query['view']);
                unset($query['layout']);
            }
        } elseif (isset($query['view'])
            && ($mView == $query['view'])
            && ($mView == 'category')
        ) {
            JLog::add('Stuff Category', JLog::DEBUG, 'com_roughcheck');
            if (isset($query['layout'])
                && ($mLayout == $query['layout'])
                && ! isset($query['id'])
            ) {
                unset($query['view']);
                unset($query['layout']);
            }
        } elseif (isset($query['view'])
            && ($mView == $query['view'])
            && ($mView == 'categories')
        ) {
            JLog::add('Stuff Categories', JLog::DEBUG, 'com_roughcheck');
            if (isset($query['layout'])
                && ($mLayout == $query['layout'])
                && ! isset($query['id'])
            ) {
                unset($query['view']);
                unset($query['layout']);
            }
        } elseif (isset($query['view'])
            && ($mView == $query['view'])
            && ($mView == 'featured')
        ) {
            JLog::add('Stuff Featured', JLog::DEBUG, 'com_roughcheck');
            if (isset($query['layout'])
                && ($mLayout == $query['layout'])
                && ! isset($query['id'])
            ) {
                unset($query['view']);
                unset($query['layout']);
            }
        } elseif (isset($query['view'])) {
            if (isset($query['view'])) {
                $segments[] = $query['view'];
                unset($query['view']);
            } else {
                $segments[] = '-';
            }
            if (isset($query['layout'])) {
                $segments[] = $query['layout'];
                unset($query['layout']);
            } else {
                $segments[] = '-';
            }
            if (isset($query['id'])) {
                $segments[] = $query['id'];
                unset($query['id']);
            } else {
                $segments[] = '0';
            }
        }

        return $segments;
    }

    /**
     * Parse the segments of a URL.
     *
     * @param array &$segments The segments of the URL to parse.
     *
     * @return array The URL attributes to be used by the application.
     *
     * @since 3.3
     */
    public function parse(&$segments)
    {
        $vars = array();

        //Get the active menu item.
        $app    = JFactory::getApplication();
        $menu   = $app->getMenu();
        $item   = $menu->getActive();
        $params = JComponentHelper::getParams('com_roughcheck');
        $advanced = $params->get('sef_advanced_link', 0);

        // Count route segments
        $count = count($segments);

        $vars['view'] = $segments[0];
        $vars['layout'] = $segments[1];
        if (empty($segments[2])) {
            $vars['id'] = 0;
        } else {
            $vars['id'] = $segments[2];
        }

        return $vars;
    }
}

/**
* Roughcheck router functions
*
* These functions are proxys for the new router interface
* for old SEF extensions.
*
* @param array &$query An array of URL arguments
*
* @return array The URL arguments to use to assemble the subsequent URL.
*
* @deprecated 4.0 Use Class based routers instead
*/
function RoughcheckBuildRoute(&$query)
{
    $router = new RoughcheckRouter;

    return $router->build($query);
}

/**
* Roughcheck router functions
*
* These functions are proxys for the new router interface
* for old SEF extensions.
*
* @param array $segments The segments of the URL to parse.
*
* @return array The URL attributes to be used by the application.
*
* @deprecated 4.0 Use Class based routers instead
*/
function RoughcheckParseRoute($segments)
{
    $router = new RoughcheckRouter;

    return $router->parse($segments);
}
