<?php
/**
* Assessment response table
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @version    SVN: $Id: assessmentresponse.php 320 2014-09-04 12:28:43Z alan $
* @link       http://p-o.co.uk/
*/

defined('_JEXEC') or die('Restricted access');

/**
* Assessment response table class
*
* PHP version 5.4
*
* @category   Joomla_Component
* @package    Roughcheck
* @subpackage Com_Roughcheck
* @author     Alan Hicks <ahicks@p-o.co.uk>
* @copyright  2012-2014 Persistent Objects Ltd
* @license    GNU General Public License version 3 or later; see LICENSE.txt
*
* @link       http://p-o.co.uk/
*/
class TableAssessmentresponse extends JTable
{

	/**
	* Constructor
	*
	* @param object &$db Database connector object
	*/
	function __construct( &$db )
	{
		parent::__construct('#__roughcheck_assessment_responses', 'id', $db);
	}

	/**
	* Rule check
	*
	* @return true if valid else false
	*/
	function check()
	{
		if (trim($this->assessment_id) == 0) {
			$this->setError(JText::_('COM_ROUGHCHECK_ERROR_ROUGHCHECK_ASSESSMENT'));
			return false;
		}
		if (trim($this->question_id) == 0) {
			$this->setError(JText::_('COM_ROUGHCHECK_ERROR_ROUGHCHECK_QUESTION'));
			return false;
		}

		return true;
	}

	/**
	* Overload the store method for the Responses table.
	*
	* @param boolean $updateNulls Toggle whether null values should be updated.
	*
	* @return	boolean	True on success, false on failure.
	*/
	public function store($updateNulls = false)
	{
		$date	= JFactory::getDate();
		$user	= JFactory::getUser();

		if (!intval($this->modified)) {
			$this->modified = $date->toSQL();
		}
		if (empty($this->modified_by)) {
			$this->modified_by = $user->get('id');
		}
		if (!intval($this->created)) {
			$this->created = $date->toSQL();
		}
		if (empty($this->created_by)) {
			$this->created_by = $user->get('id');
		}
		if (empty($this->checked_out_time)) {
			$this->checked_out_time = $date->toSQL();
		}
		if (empty($this->checked_out)) {
			$this->checked_out = 0;
		}

		// Postgresql database fix
		$db = $this->getDbo();
		if ($db->name == 'postgresql') {
			if ($this->response) {
				$this->response = 't';
			} else {
				$this->response = 'f';
			}
			$this->checked_out_time = $date->toSQL();
		}

		// Attempt to store the user data.
		return parent::store($updateNulls);
	}

}
